@@ -26,6 +26,9 @@
 (require 'helm-types)
 (require 'helm-help)
 
+(defvar helm-ff-default-directory)
+(declare-function helm-read-file-name "helm-mode")
+
 
 (defgroup helm-locate nil
   "Locate related Applications and libraries for Helm."
@@ -416,13 +419,17 @@ Sort is done on basename of CANDIDATES."
 (defun helm-locate-init-subdirs ()
   (with-temp-buffer
     (call-process-shell-command
-     (format helm-locate-recursive-dirs-command
-	     (if (string-match-p "\\`es" helm-locate-recursive-dirs-command)
-                 ;; Fix W32 paths.
-		 (replace-regexp-in-string
-                  "/" "\\\\\\\\" (helm-attr 'basedir))
+     (if (string-match-p "\\`fd" helm-locate-recursive-dirs-command)
+         (format helm-locate-recursive-dirs-command
+                 ;; fd pass path at end.
+                 (helm-attr 'subdir) (helm-attr 'basedir))
+       (format helm-locate-recursive-dirs-command
+	       (if (string-match-p "\\`es" helm-locate-recursive-dirs-command)
+                   ;; Fix W32 paths.
+		   (replace-regexp-in-string
+                    "/" "\\\\\\\\" (helm-attr 'basedir))
                  (helm-attr 'basedir))
-	     (helm-attr 'subdir))
+	       (helm-attr 'subdir)))
      nil t nil)
     (buffer-string)))
 
