@@ -24,6 +24,8 @@
 (require 'xml)
 (require 'browse-url)
 
+(declare-function helm-comp-read "helm-mode")
+
 
 (defgroup helm-net nil
   "Net related applications and libraries for Helm."
@@ -273,7 +275,6 @@ Can be \"-new-tab\" (default) or \"-new-window\"."
     (,browse-url-mozilla-program . browse-url-mozilla)
     (,browse-url-galeon-program . browse-url-galeon)
     (,browse-url-netscape-program . browse-url-netscape)
-    (,browse-url-mosaic-program . browse-url-mosaic)
     (,browse-url-xterm-program . browse-url-text-xterm)
     ("emacs" . eww-browse-url))
   "*Alist of \(executable . function\) to try to find a suitable url browser.")
